nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

OutSel1

Struct OutSel1 

#[repr(transparent)]
pub struct OutSel1(pub u32);
Trigger Source IN16 to IN31 selector.

Tuple Fields

0: u32

Implementations

Source

impl OutSel1

pub const fn in16_se_ln(&self) -> u8

Selects SPC VDD_SYS_LVD detect as a trigger source.

pub const fn set_in16_se_ln(&mut self, val: u8)

Selects SPC VDD_SYS_LVD detect as a trigger source.

pub const fn in17_se_ln(&self) -> u8

Selects SPC VDD_IO_LVD detect as a trigger source.

pub const fn set_in17_se_ln(&mut self, val: u8)

Selects SPC VDD_IO_LVD detect as a trigger source.

pub const fn in18_se_ln(&self) -> u8

Reserved.

pub const fn set_in18_se_ln(&mut self, val: u8)

Reserved.

pub const fn in19_se_ln(&self) -> u8

Selects VBAT temperature tamper output event as a trigger source.

pub const fn set_in19_se_ln(&mut self, val: u8)

Selects VBAT temperature tamper output event as a trigger source.

pub const fn in20_se_ln(&self) -> u8

Selects VBAT clock tamper output event as a trigger source.

pub const fn set_in20_se_ln(&mut self, val: u8)

Selects VBAT clock tamper output event as a trigger source.

pub const fn in21_se_ln(&self) -> u8

Selects INTM interrupt monitor error 0 event as a trigger source.

pub const fn set_in21_se_ln(&mut self, val: u8)

Selects INTM interrupt monitor error 0 event as a trigger source.

pub const fn in22_se_ln(&self) -> u8

Selects INTM interrupt monitor error 1 event as a trigger source.

pub const fn set_in22_se_ln(&mut self, val: u8)

Selects INTM interrupt monitor error 1 event as a trigger source.

pub const fn in23_se_ln(&self) -> u8

Selects INTM interrupt monitor error 2 event as a trigger source.

pub const fn set_in23_se_ln(&mut self, val: u8)

Selects INTM interrupt monitor error 2 event as a trigger source.

pub const fn in24_se_ln(&self) -> u8

Selects INTM interrupt monitor error 3 event as a trigger source.

pub const fn set_in24_se_ln(&mut self, val: u8)

Selects INTM interrupt monitor error 3 event as a trigger source.

pub const fn in25_se_ln(&self) -> u8

Selects MSF SOCTRIM 0 ECC error event as a trigger source.

pub const fn set_in25_se_ln(&mut self, val: u8)

Selects MSF SOCTRIM 0 ECC error event as a trigger source.

pub const fn in26_se_ln(&self) -> u8

Selects MSF SOCTRIM 1 ECC error event as a trigger source.

pub const fn set_in26_se_ln(&mut self, val: u8)

Selects MSF SOCTRIM 1 ECC error event as a trigger source.

pub const fn in27_se_ln(&self) -> u8

Selects MSF SOCTRIM 2 ECC error event as a trigger source.

pub const fn set_in27_se_ln(&mut self, val: u8)

Selects MSF SOCTRIM 2 ECC error event as a trigger source.

pub const fn in28_se_ln(&self) -> u8

Selects MSF SOCTRIM 3 ECC error event as a trigger source.

pub const fn set_in28_se_ln(&mut self, val: u8)

Selects MSF SOCTRIM 3 ECC error event as a trigger source.

pub const fn in29_se_ln(&self) -> u8

Selects MSF SOCTRIM 4 ECC error event as a trigger source.

pub const fn set_in29_se_ln(&mut self, val: u8)

Selects MSF SOCTRIM 4 ECC error event as a trigger source.

pub const fn in30_se_ln(&self) -> u8

Selects MSF SOCTRIM 5 ECC error event as a trigger source.

pub const fn set_in30_se_ln(&mut self, val: u8)

Selects MSF SOCTRIM 5 ECC error event as a trigger source.

pub const fn in31_se_ln(&self) -> u8

Selects MSF SOCTRIM 6 ECC error event as a trigger source.

pub const fn set_in31_se_ln(&mut self, val: u8)

Selects MSF SOCTRIM 6 ECC error event as a trigger source.