nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

OutSel

Struct OutSel 

#[repr(transparent)]
pub struct OutSel(pub u32);
Trigger Source IN0 to IN15 selector

Tuple Fields

0: u32

Implementations

Source

impl OutSel

pub const fn in0_seln(&self) -> u8

Selects digital glitch detector as a trigger source.

pub const fn set_in0_seln(&mut self, val: u8)

Selects digital glitch detector as a trigger source.

pub const fn in1_seln(&self) -> u8

Selects TDET event as a trigger source.

pub const fn set_in1_seln(&mut self, val: u8)

Selects TDET event as a trigger source.

pub const fn in2_seln(&self) -> u8

Selects Code Watchdog 0 event as a trigger source.

pub const fn set_in2_seln(&mut self, val: u8)

Selects Code Watchdog 0 event as a trigger source.

pub const fn in3_seln(&self) -> u8

Selects VBAT voltage tamper event as a trigger source.

pub const fn set_in3_seln(&mut self, val: u8)

Selects VBAT voltage tamper event as a trigger source.

pub const fn in4_seln(&self) -> u8

Selects low-voltage event on VDD_CORE rail as a trigger source.

pub const fn set_in4_seln(&mut self, val: u8)

Selects low-voltage event on VDD_CORE rail as a trigger source.

pub const fn in5_seln(&self) -> u8

Selects Watchdog 0 timer event as a trigger source.

pub const fn set_in5_seln(&mut self, val: u8)

Selects Watchdog 0 timer event as a trigger source.

pub const fn in6_seln(&self) -> u8

Selects Flash ECC mismatch event as a trigger source.

pub const fn set_in6_seln(&mut self, val: u8)

Selects Flash ECC mismatch event as a trigger source.

pub const fn in7_seln(&self) -> u8

Selects AHB secure bus or MBC bus illegal access event as a trigger source.

pub const fn set_in7_seln(&mut self, val: u8)

Selects AHB secure bus or MBC bus illegal access event as a trigger source.

pub const fn in8_seln(&self) -> u8

Selects ELS error event as a trigger source.

pub const fn set_in8_seln(&mut self, val: u8)

Selects ELS error event as a trigger source.

pub const fn in9_seln(&self) -> u8

Selects SPC VDD_CORE glitch detector as a trigger source.

pub const fn set_in9_seln(&mut self, val: u8)

Selects SPC VDD_CORE glitch detector as a trigger source.

pub const fn in10_seln(&self) -> u8

Selects PKC error event as a trigger source.

pub const fn set_in10_seln(&mut self, val: u8)

Selects PKC error event as a trigger source.

pub const fn in11_seln(&self) -> u8

Selects Code Watchdog 1 event as a trigger source.

pub const fn set_in11_seln(&mut self, val: u8)

Selects Code Watchdog 1 event as a trigger source.

pub const fn in12_seln(&self) -> u8

Selects Watchdog 1 timer event as a trigger source.

pub const fn set_in12_seln(&mut self, val: u8)

Selects Watchdog 1 timer event as a trigger source.

pub const fn in13_seln(&self) -> u8

Selects FREQME out of range status output as a trigger source.

pub const fn set_in13_seln(&mut self, val: u8)

Selects FREQME out of range status output as a trigger source.

pub const fn in14_seln(&self) -> u8

Selects software event 0 as a trigger source.

pub const fn set_in14_seln(&mut self, val: u8)

Selects software event 0 as a trigger source.

pub const fn in15_seln(&self) -> u8

Selects software event 1 as a trigger source.

pub const fn set_in15_seln(&mut self, val: u8)

Selects software event 1 as a trigger source.